@@ -2,8 +2,7 @@ import asyncio
 from pathlib import Path
 from typing import Any
 
-import msgspec
-from msgspec import Struct
+from msgspec import Struct, convert
 import yt_dlp
 
 from ..config import pconfig
@@ -55,7 +54,7 @@ class YtdlpDownloader:
 
         Args:
             url (str): url address
-            cookiefile (Path | None, optional): cookie file path. Defaults to None.
+            cookiefile (Path | None ): cookie file path. Defaults to None.
 
         Returns:
             dict[str, str]: video info
@@ -73,7 +72,7 @@ class YtdlpDownloader:
             if not info_dict:
                 raise ParseException("获取视频信息失败")
 
-        video_info = msgspec.convert(info_dict, VideoInfo)
+        video_info = convert(info_dict, VideoInfo)
         self._video_info_mapping[url] = video_info
         return video_info
 
@@ -83,7 +82,7 @@ class YtdlpDownloader:
 
         Args:
             url (str): url address
-            cookiefile (Path | None, optional): cookie file path. Defaults to None.
+            cookiefile (Path | None): cookie file path. Defaults to None.
 
         Returns:
             Path: video file path
@@ -116,7 +115,7 @@ class YtdlpDownloader:
 
         Args:
             url (str): url address
-            cookiefile (Path | None, optional): cookie file path. Defaults to None.
+            cookiefile (Path | None): cookie file path. Defaults to None.
 
         Returns:
             Path: audio file path
