@@ -5,13 +5,17 @@ from .data import ParseResult as ParseResult
 from .douyin import DouyinParser as DouyinParser
 from .kuaishou import KuaiShouParser as KuaiShouParser
 from .nga import NGAParser as NGAParser
-from .tiktok import TikTokParser as TikTokParser
 from .twitter import TwitterParser as TwitterParser
 from .weibo import WeiBoParser as WeiBoParser
 from .xiaohongshu import XiaoHongShuParser as XiaoHongShuParser
-from .youtube import YouTubeParser as YouTubeParser
 from .bilibili import BilibiliParser as BilibiliParser
 
+from ..download import YTDLP_DOWNLOADER
+
+if YTDLP_DOWNLOADER is not None:
+    from .tiktok import TikTokParser as TikTokParser
+    from .youtube import YouTubeParser as YouTubeParser
+
 __all__ = [
     "ParseResult",
 ]
