@@ -7,15 +7,15 @@ from typing import ClassVar
 from typing_extensions import override
 
 from bs4 import BeautifulSoup, Tag
-import httpx
+from httpx import AsyncClient, HTTPError
 
 from ..exception import ParseException
-from .base import BaseParser, Platform
+from .base import BaseParser, Platform, PlatformEnum
 
 
 class NGAParser(BaseParser):
     # 平台信息
-    platform: ClassVar[Platform] = Platform(name="nga", display_name="NGA")
+    platform: ClassVar[Platform] = Platform(name=PlatformEnum.NGA, display_name="NGA")
 
     # URL 正则表达式模式（keyword, pattern）
     patterns: ClassVar[list[tuple[str, str]]] = [
@@ -38,29 +38,19 @@ class NGAParser(BaseParser):
             "Upgrade-Insecure-Requests": "1",
         }
         self.headers.update(extra_headers)
+        self.base_img_url = "https://img.nga.178.com/attachments"
 
     @staticmethod
     def nga_url(tid: str | int) -> str:
         return f"https://nga.178.com/read.php?tid={tid}"
 
     @override
-    async def parse(self, matched: re.Match[str]):
-        """解析 URL 获取内容信息并下载资源
-
-        Args:
-            matched: 正则表达式匹配对象，由平台对应的模式匹配得到
-
-        Returns:
-            ParseResult: 解析结果
-
-        Raises:
-            ParseException: 解析失败时抛出
-        """
+    async def parse(self, keyword: str, searched: re.Match[str]):
         # 从匹配对象中获取原始URL
-        tid = matched.group("tid")
+        tid = searched.group("tid")
         url = self.nga_url(tid)
 
-        async with httpx.AsyncClient(headers=self.headers, timeout=self.timeout, follow_redirects=True) as client:
+        async with AsyncClient(headers=self.headers, timeout=self.timeout, follow_redirects=True) as client:
             try:
                 # 第一次请求可能返回403，但包含设置cookie的JavaScript
                 resp = await client.get(url)
@@ -86,7 +76,7 @@ class NGAParser(BaseParser):
 
                         resp = await client.get(retry_url)
 
-            except httpx.HTTPError as e:
+            except HTTPError as e:
                 raise ParseException(f"请求失败: {e}")
 
         if resp.status_code != 200:
@@ -140,9 +130,13 @@ class NGAParser(BaseParser):
         # 提取文本 - postcontent0
         text = None
         content_tag = soup.find(id="postcontent0")
+        contents = []
         if content_tag and isinstance(content_tag, Tag):
             text = content_tag.get_text("\n", strip=True)
             # 清理 BBCode 标签并限制长度
+            img_urls: list[str] = re.findall(r"\[img\](.*?)\[/img\]", text)
+            img_urls = [self.base_img_url + url[1:] for url in img_urls]
+            contents.extend(self.create_image_contents(img_urls))
             text = self.clean_nga_text(text)
 
         return self.result(
@@ -150,6 +144,7 @@ class NGAParser(BaseParser):
             text=text,
             url=url,
             author=author,
+            contents=contents,
             timestamp=timestamp,
         )
 
