@@ -5,14 +5,11 @@ from .base import BaseRenderer
 from .common import CommonRenderer
 from .default import DefaultRenderer
 
-_DEFAULT_RENDERER = DefaultRenderer()
-_COMMON_RENDERER = CommonRenderer()
-
 match pconfig.render_type:
     case RenderType.common:
-        RENDERER = _COMMON_RENDERER
+        RENDERER = CommonRenderer
     case RenderType.default:
-        RENDERER = _DEFAULT_RENDERER
+        RENDERER = DefaultRenderer
     case RenderType.htmlkit:
         RENDERER = None
 
@@ -20,7 +17,7 @@ match pconfig.render_type:
 def get_renderer(platform: str) -> BaseRenderer:
     """根据平台名称获取对应的 Renderer 类"""
     if RENDERER:
-        return RENDERER
+        return RENDERER()
 
     try:
         module = importlib.import_module("." + platform, package=__name__)
@@ -31,12 +28,12 @@ def get_renderer(platform: str) -> BaseRenderer:
         # 如果没有对应的 Renderer 模块或类，返回默认的 Renderer
         pass
     # fallback to default renderer
-    return _COMMON_RENDERER
+    return CommonRenderer()
 
 
 from nonebot import get_driver
 
 
 @get_driver().on_startup
-async def load_font():
-    _COMMON_RENDERER.load_resources()
+async def load_resources():
+    CommonRenderer.load_resources()
