@@ -44,6 +44,7 @@ class BaseRenderer(ABC):
         """
         failed_count = 0
         forwardable_segs: list[ForwardNodeInner] = []
+        dynamic_segs: list[ForwardNodeInner] = []
 
         for cont in chain(result.contents, result.repost.contents if result.repost else ()):
             try:
@@ -65,20 +66,24 @@ class BaseRenderer(ABC):
                 case ImageContent():
                     forwardable_segs.append(UniHelper.img_seg(path))
                 case DynamicContent():
-                    forwardable_segs.append(UniHelper.video_seg(path))
+                    dynamic_segs.append(UniHelper.video_seg(path))
                 case GraphicsContent() as graphics:
                     graphics_msg = UniHelper.img_seg(path)
                     if graphics.text is not None:
                         graphics_msg = graphics.text + graphics_msg
+                    if graphics.alt is not None:
+                        graphics_msg = graphics_msg + graphics.alt
                     forwardable_segs.append(graphics_msg)
 
         if forwardable_segs:
             if pconfig.need_forward_contents or len(forwardable_segs) > 4:
-                forward_msg = UniHelper.construct_forward_message(forwardable_segs)
+                forward_msg = UniHelper.construct_forward_message(forwardable_segs + dynamic_segs)
                 yield UniMessage(forward_msg)
             else:
-                for seg in forwardable_segs:
-                    yield UniMessage(seg)
+                yield UniMessage(forwardable_segs)
+
+                if dynamic_segs:
+                    yield UniMessage(UniHelper.construct_forward_message(dynamic_segs))
 
         if failed_count > 0:
             message = f"{failed_count} 项媒体下载失败"
